@@ -43,6 +43,7 @@
 //
 //----------------------------------------------------------------
 
+#include <ImathPlatform.h>
 #include <ImathFun.h>
 #include <ImathExc.h>
 #include <ImathVec.h>
@@ -2331,8 +2332,7 @@ Matrix44<T>::operator *= (const Matrix44<T> &v)
 }
 
 template <class T>
-Matrix44<T>
-inline
+inline Matrix44<T>
 Matrix44<T>::operator * (const Matrix44<T> &v) const
 {
     Matrix44 tmp (T (0));
@@ -2341,10 +2341,6 @@ Matrix44<T>::operator * (const Matrix44<T> &v) const
     return tmp;
 }
 
-#if defined (PLATFORM_WIN32)
-#define restrict
-#endif
-
 template <class T>
 void
 Matrix44<T>::multiply (const Matrix44<T> &a,
